@@ -59,7 +59,7 @@ mod tests {
         let (lat, lon) = (52.0, 4.0);
         let az = 45.0;
         let dist = 10000.0;
-        let (out_latitude, out_longitude, azimuth) = Rhumb::rhumbline_direct(lat, lon, az, dist);
+        let (out_latitude, out_longitude, _out_azimuth) = Rhumb::rhumbline_direct(lat, lon, az, dist);
         assert_eq!((out_latitude * 100.0).round() / 100.0, 52.06);
         assert_eq!((out_longitude * 100.0).round() / 100.0, 4.10);
     }
